==> spring-social-facebook-1.0.1.RELEASE-sources.jar: org/springframework/social/facebook/api/impl/json/CheckinMixin.java <==
/*
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.social.facebook.api.impl.json;

import java.util.Date;
import java.util.List;

import org.codehaus.jackson.annotate.JsonCreator;
import org.codehaus.jackson.annotate.JsonIgnoreProperties;
import org.codehaus.jackson.annotate.JsonProperty;
import org.codehaus.jackson.map.annotate.JsonDeserialize;
import org.springframework.social.facebook.api.Comment;
import org.springframework.social.facebook.api.Page;
import org.springframework.social.facebook.api.Reference;

/**
 * Annotated mixin to add Jackson annotations to Checkin. 
 * @author Craig Walls
 */
@JsonIgnoreProperties(ignoreUnknown = true)
abstract class CheckinMixin {

	@JsonCreator
	CheckinMixin(
			@JsonProperty("id") String id, 
			@JsonProperty("place") Page place, 
			@JsonProperty("from") Reference from, 
			@JsonProperty("application") Reference application, 
			@JsonProperty("created_time") Date createdTime) {}
	
	@JsonProperty("message")
	String message;

	@JsonProperty("comments")
	@JsonDeserialize(using = CommentListDeserializer.class)
	List<Comment> comments;
	
	@JsonProperty("likes")
	@JsonDeserialize(using = ReferenceListDeserializer.class)
	List<Reference> likes;

	@JsonProperty("tags")
	@JsonDeserialize(using = ReferenceListDeserializer.class)
	List<Reference> tags;

}

==> spring-social-facebook-1.0.3.RELEASE-sources.jar: org/springframework/social/facebook/api/impl/json/CheckinMixin.java <==
/*
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.social.facebook.api.impl.json;

import java.util.Date;
import java.util.List;

import org.codehaus.jackson.annotate.JsonCreator;
import org.codehaus.jackson.annotate.JsonIgnoreProperties;
import org.codehaus.jackson.annotate.JsonProperty;
import org.codehaus.jackson.map.annotate.JsonDeserialize;
import org.springframework.social.facebook.api.Comment;
import org.springframework.social.facebook.api.Page;
import org.springframework.social.facebook.api.Reference;

/**
 * Annotated mixin to add Jackson annotations to Checkin. 
 * @author Craig Walls
 */
@JsonIgnoreProperties(ignoreUnknown = true)
abstract class CheckinMixin {

	@JsonCreator
	CheckinMixin(
			@JsonProperty("id") String id, 
			@JsonProperty("place") Page place, 
			@JsonProperty("from") Reference from, 
			@JsonProperty("application") Reference application, 
			@JsonProperty("created_time") Date createdTime) {}
	
	@JsonProperty("message")
	String message;

	@JsonProperty("comments")
	@JsonDeserialize(using = CommentListDeserializer.class)
	List<Comment> comments;
	
	@JsonProperty("likes")
	@JsonDeserialize(using = ReferenceListDeserializer.class)
	List<Reference> likes;

	@JsonProperty("with_tags")
	@JsonDeserialize(using = ReferenceListDeserializer.class)
	List<Reference> tags;

}
